# Generated by Django 4.0.4 on 2022-05-12 11:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cards', '0004_add_multi_class_group'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cardstring',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='cardtag',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False, verbose_name='ID'),
        ),
    ]
