# Generated by Django 4.2.1 on 2023-06-02 18:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cards', '0005_explicit_primary_keys'),
    ]

    operations = [
        migrations.AddField(
            model_name='card',
            name='multiple_classes',
            field=models.IntegerField(default=0),
        ),
    ]
