# Generated by Django 2.0.6 on 2019-07-01 19:20

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("cards", "0002_auto_20180321_1313"),
    ]

    operations = [
        migrations.AlterField(
            model_name="card",
            name="name",
            field=models.CharField(max_length=64),
        ),
    ]
